package com.zt.demo.pojo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import jakarta.validation.constraints.*;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
@Data
public class RequestParams implements Serializable {
    @NotBlank(message = "appId不能为空")
    private String appId;//应用id
    @NotBlank(message ="签名不能为空")
    private String sign;//签名
    @NotNull(message ="时间戳不能为空")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long reqTime;//时间戳
    @NotNull(message ="goodsId不能为空")
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    private Long goodsId;//商品id
    @NotNull(message ="数量不能为空")
    @DecimalMin(value = "1",message = "最小值1")
    private Integer amount;//数量
    @DecimalMin(value="0",message = "最小值")
    @DecimalMax(value="9999",message = "最大值")
    private BigDecimal price;//价格
    @NotBlank(message ="手机号不能为空")
    @Pattern(regexp = "^((13[0-9])|(14[0-9])|(15[0-9])|(166)|(17[0-9])|(18[0-9])|(19[0-9]))\\d{8}$",message = "手机号格式错误")
    private String mobile;//手机号
    @NotNull(message ="sign 不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8",shape = JsonFormat.Shape.STRING)
    private Date nowDate;//当前时间
}
